#########################################
Detector Utilities (:mod:`gwpy.detector`)
#########################################

.. automodule:: gwpy.detector

.. seealso::

    - **User Guide**: :doc:`/detector/channel`

.. automodapi:: gwpy.detector
    :include-all-objects:
    :no-heading:
    :no-main-docstr:
